==> lowcode-editor-skeleton-2.0.5.tgz: package/es/components/settings/components/array-advance-table/advance-content/index.js <==
import _Space from "antd/es/space";
import _extends from "@babel/runtime/helpers/extends";
import _objectWithoutPropertiesLoose from "@babel/runtime/helpers/objectWithoutPropertiesLoose";
import _Empty from "antd/es/empty";
var _excluded = ["className", "rowSelectionOptions"];
import { observer, RecursionField, useFieldSchema } from '@formily/react';
import cls from 'classnames';
import React, { useRef, useState } from 'react';
import useStyle from './style';
import { usePrefixCls } from '@formily/antd-v5/lib/__builtins__';
import { ArrayBase } from '@formily/antd-v5';
import { SubSlotProvider } from '../../../context';
import { GridManagerContext, isColumnComponent, LOWCODE_NODE_ID, RowSelectedContext, useAddition, useArrayTableColumns, useArrayTableSources, useBatchRemove, useValueMode } from '../common';
import { SideContent } from '../side-content';
import { useHandleCellEditChange } from '../hooks';
import { useCommonUI, useSelected, useSettingsMain } from '../../../../../hooks';
import { Settings } from '../../../settings-primary-pane';
var ChildrenSettings = function ChildrenSettings(_ref) {
  var childrenNode = _ref.childrenNode;
  if (!childrenNode) return /*#__PURE__*/React.createElement(_Empty, {
    description: "\u8BF7\u5148\u5728\u8868\u683C\u9009\u62E9\u7F16\u8F91\u9879"
  });
  var settings = childrenNode.settingEntry;
  return /*#__PURE__*/React.createElement(Settings, {
    settings: settings
  });
};
export var AdvanceContent = observer(function (_ref2) {
  var className = _ref2.className,
    rowSelectionOptions = _ref2.rowSelectionOptions,
    props = _objectWithoutPropertiesLoose(_ref2, _excluded);
  var selected = useSelected();
  var main = useSettingsMain();
  var slotRef = useRef(null);
  var valueMode = useValueMode();
  var array = ArrayBase.useArray();
  var field = array.field;
  var schema = useFieldSchema();
  var _useCommonUI = useCommonUI(),
    AdvanceTable = _useCommonUI.AdvanceTable;
  var _AdvanceTable$useGrid = AdvanceTable.useGrid(),
    gridManagerRef = _AdvanceTable$useGrid.gridManagerRef,
    gridApiRef = _AdvanceTable$useGrid.gridApiRef,
    onGridReady = _AdvanceTable$useGrid.onGridReady;
  var _AdvanceTable$useRowS = AdvanceTable.useRowSelection(gridApiRef, _extends({}, rowSelectionOptions, {
      rowkey: LOWCODE_NODE_ID
    })),
    rowSelection = _AdvanceTable$useRowS.rowSelection,
    selectedKeys = _AdvanceTable$useRowS.selectedKeys;
  schema['x-data'] = 'advance';
  var prefixCls = usePrefixCls('advance-content');
  var _useStyle = useStyle(prefixCls),
    wrapSSR = _useStyle[0],
    hashId = _useStyle[1];
  var dataSource = Array.isArray(field.value) ? field.value.slice() : [];
  var sources = useArrayTableSources(field, schema, 'advance');
  var columns = useArrayTableColumns(dataSource, field, sources);
  var addition = useAddition(schema);
  var batchRemove = useBatchRemove(schema);
  var _useState = useState(null),
    childrenNode = _useState[0],
    setChildrenNode = _useState[1];
  var onSelectionChanged = function onSelectionChanged(event) {
    var childrenNode = main.settings.getNode().document.getNode(event.selectedNodes[0].id);
    setChildrenNode(childrenNode);
  };
  var handleCellEditChange = useHandleCellEditChange(valueMode, dataSource);
  console.log('---sources', sources, columns, dataSource);
  var handleRowDragEnd = function handleRowDragEnd(params) {
    var overIndex = params.overIndex,
      overNode = params.overNode;
    var node = selected.document.getNodeById(overNode.id);
    var nodeIndex = selected.children.indexOf(node);
    selected.children.insert(node, overIndex > nodeIndex ? overIndex + 1 : overIndex);
  };
  var children = wrapSSR(/*#__PURE__*/React.createElement("div", {
    ref: slotRef,
    className: cls(prefixCls, hashId)
  }, /*#__PURE__*/React.createElement("div", {
    className: prefixCls + "-left"
  }, /*#__PURE__*/React.createElement(_Space, {
    className: cls(prefixCls + "-toobar")
  }, addition, batchRemove, /*#__PURE__*/React.createElement(SideContent, null)), /*#__PURE__*/React.createElement(AdvanceTable, _extends({
    editable: true,
    autoHeight: true,
    animateRows: true,
    rowMultiSelectWithClick: false,
    stopEditingWhenCellsLoseFocus: true,
    rowDragManaged: true
  }, props, {
    rowkey: LOWCODE_NODE_ID,
    rowSelection: rowSelection,
    onReady: onGridReady,
    columns: columns,
    dataSource: dataSource,
    onCellEditChange: handleCellEditChange,
    onSelectionChanged: onSelectionChanged,
    onRowDragEnd: handleRowDragEnd
  })), sources.map(function (column, key) {
    if (!isColumnComponent(column.schema)) return;
    return /*#__PURE__*/React.createElement(RecursionField, {
      name: column.name,
      schema: column.schema,
      onlyRenderSelf: true,
      key: key
    });
  })), /*#__PURE__*/React.createElement("div", {
    className: prefixCls + "-right"
  }, /*#__PURE__*/React.createElement(ChildrenSettings, {
    childrenNode: childrenNode
  }))));
  return /*#__PURE__*/React.createElement(GridManagerContext.Provider, {
    value: gridManagerRef
  }, /*#__PURE__*/React.createElement(RowSelectedContext.Provider, {
    value: selectedKeys
  }, /*#__PURE__*/React.createElement(SubSlotProvider, {
    value: slotRef
  }, children)));
});

==> lowcode-editor-skeleton-2.0.7.tgz: package/es/components/settings/components/array-advance-table/advance-content/index.js <==
import _Space from "antd/es/space";
import _extends from "@babel/runtime/helpers/extends";
import _objectWithoutPropertiesLoose from "@babel/runtime/helpers/objectWithoutPropertiesLoose";
import _Empty from "antd/es/empty";
var _excluded = ["valueMode", "className", "rowSelectionOptions"];
import { observer, RecursionField, useFieldSchema } from '@formily/react';
import cls from 'classnames';
import React, { useRef, useState } from 'react';
import useStyle from './style';
import { usePrefixCls } from '@formily/antd-v5/lib/__builtins__';
import { ArrayBase } from '@formily/antd-v5';
import { SubSlotProvider } from '../../../context';
import { GridManagerContext, isColumnComponent, LOWCODE_NODE_ID, RowSelectedContext, useAddition, useArrayTableColumns, useArrayTableSources, useBatchRemove, useFieldDataSource } from '../common';
import { SideContent } from '../side-content';
import { useCommonUI, useSelected, useSettingsMain } from '../../../../../hooks';
import { Settings } from '../../../settings-primary-pane';
import { useRowDragEnd } from '../hooks';
var ChildrenSettings = function ChildrenSettings(_ref) {
  var childrenNode = _ref.childrenNode;
  if (!childrenNode) return /*#__PURE__*/React.createElement(_Empty, {
    description: "\u8BF7\u5148\u5728\u8868\u683C\u9009\u62E9\u7F16\u8F91\u9879"
  });
  var settings = childrenNode.settingEntry;
  return /*#__PURE__*/React.createElement(Settings, {
    settings: settings
  });
};
export var AdvanceContent = observer(function (_ref2) {
  var valueMode = _ref2.valueMode,
    className = _ref2.className,
    rowSelectionOptions = _ref2.rowSelectionOptions,
    props = _objectWithoutPropertiesLoose(_ref2, _excluded);
  var selected = useSelected();
  var main = useSettingsMain();
  var slotRef = useRef(null);
  var dataSource = useFieldDataSource();
  var array = ArrayBase.useArray();
  var field = array.field;
  var schema = useFieldSchema();
  var _useCommonUI = useCommonUI(),
    AdvanceTable = _useCommonUI.AdvanceTable;
  var _AdvanceTable$useGrid = AdvanceTable.useGrid(),
    gridManagerRef = _AdvanceTable$useGrid.gridManagerRef,
    gridApiRef = _AdvanceTable$useGrid.gridApiRef,
    onGridReady = _AdvanceTable$useGrid.onGridReady;
  var _AdvanceTable$useRowS = AdvanceTable.useRowSelection(gridApiRef, _extends({}, rowSelectionOptions, {
      rowkey: LOWCODE_NODE_ID
    })),
    rowSelection = _AdvanceTable$useRowS.rowSelection,
    selectedKeys = _AdvanceTable$useRowS.selectedKeys;
  schema['x-data'] = _extends({}, schema['x-data'], {
    env: 'advance'
  });
  var prefixCls = usePrefixCls('advance-content');
  var _useStyle = useStyle(prefixCls),
    wrapSSR = _useStyle[0],
    hashId = _useStyle[1];
  var sources = useArrayTableSources(field, schema, 'advance');
  var columns = useArrayTableColumns(dataSource, field, sources);
  var addition = useAddition(schema);
  var batchRemove = useBatchRemove(schema);
  var _useState = useState(null),
    childrenNode = _useState[0],
    setChildrenNode = _useState[1];
  var onSelectionChanged = function onSelectionChanged(event) {
    var _event$selectedNodes, _event$selectedNodes$;
    if (valueMode !== 'children') return;
    if (!((_event$selectedNodes = event.selectedNodes) !== null && _event$selectedNodes !== void 0 && _event$selectedNodes.length)) {
      setChildrenNode(null);
      return;
    }
    var childrenNode = main.settings.getNode().document.getNode((_event$selectedNodes$ = event.selectedNodes[0]) === null || _event$selectedNodes$ === void 0 ? void 0 : _event$selectedNodes$.id);
    setChildrenNode(childrenNode);
  };
  var handleRowDragEnd = useRowDragEnd(selected);
  var children = wrapSSR(/*#__PURE__*/React.createElement("div", {
    ref: slotRef,
    className: cls(prefixCls, hashId)
  }, /*#__PURE__*/React.createElement("div", {
    className: prefixCls + "-left"
  }, /*#__PURE__*/React.createElement(_Space, {
    className: cls(prefixCls + "-toobar")
  }, addition, batchRemove, /*#__PURE__*/React.createElement(SideContent, null)), /*#__PURE__*/React.createElement(AdvanceTable, _extends({
    editable: true,
    autoHeight: true,
    animateRows: true,
    rowMultiSelectWithClick: false,
    stopEditingWhenCellsLoseFocus: true,
    rowDragManaged: true
  }, props, {
    className: cls(prefixCls + "-grid", className),
    rowkey: LOWCODE_NODE_ID,
    rowSelection: rowSelection,
    onReady: onGridReady,
    columns: columns,
    dataSource: dataSource,
    onSelectionChanged: onSelectionChanged,
    onRowDragEnd: handleRowDragEnd
  })), sources.map(function (column, key) {
    if (!isColumnComponent(column.schema)) return;
    return /*#__PURE__*/React.createElement(RecursionField, {
      name: column.name,
      schema: column.schema,
      onlyRenderSelf: true,
      key: key
    });
  })), /*#__PURE__*/React.createElement("div", {
    className: prefixCls + "-right"
  }, /*#__PURE__*/React.createElement(ChildrenSettings, {
    childrenNode: childrenNode
  }))));
  return /*#__PURE__*/React.createElement(GridManagerContext.Provider, {
    value: gridManagerRef
  }, /*#__PURE__*/React.createElement(RowSelectedContext.Provider, {
    value: selectedKeys
  }, /*#__PURE__*/React.createElement(SubSlotProvider, {
    value: slotRef
  }, children)));
});
